[E-devel] How to get the buffer of current evas

2011-06-21 Thread suxia li


Hi,
  Here i want to get the buffer of current evas, so i tried by the 2 API , 
firstly get the ecore evas, then get the buffer pixels of current Ecore_Evas, 
but the second API return NULL. is there any one help me on this issue, thanks 
in advance.

ecore_evas_ecore_evas_get(const Evas *e);
ecore_evas_buffer_pixels_get(Ecore_Evas *ee);

Best Regards
--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] How to get the buffer of current evas

2011-06-21 Thread Atton Jonathan
Evas is optimized, now Evas does not use a buffer. Data are in the cloud !

2011/6/21 suxia li suxia...@samsung.com



 Hi,
  Here i want to get the buffer of current evas, so i tried by the 2 API ,
 firstly get the ecore evas, then get the buffer pixels of current
 Ecore_Evas, but the second API return NULL. is there any one help me on this
 issue, thanks in advance.

 ecore_evas_ecore_evas_get(const Evas *e);
 ecore_evas_buffer_pixels_get(Ecore_Evas *ee);

 Best Regards

 --
 EditLive Enterprise is the world's most technically advanced content
 authoring tool. Experience the power of Track Changes, Inline Image
 Editing and ensure content is compliant with Accessibility Checking.
 http://p.sf.net/sfu/ephox-dev2dev
 ___
 enlightenment-devel mailing list
 enlightenment-devel@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-devel




-- 
Regards.
--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] How to get the buffer of current evas

2011-06-21 Thread Vincent Torri



On Tue, 21 Jun 2011, Atton Jonathan wrote:


Evas is optimized, now Evas does not use a buffer. Data are in the cloud !


but he is using the buffer engine with ecore_evas, so it should work. 
Maybe a small test case would be helpful


Vincent



2011/6/21 suxia li suxia...@samsung.com




Hi,
 Here i want to get the buffer of current evas, so i tried by the 2 API ,
firstly get the ecore evas, then get the buffer pixels of current
Ecore_Evas, but the second API return NULL. is there any one help me on this
issue, thanks in advance.

ecore_evas_ecore_evas_getÿÿconst Evas *e
ecore_evas_buffer_pixels_getÿÿEcore_Evas *ee

Best Regards

--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel





--
Regards.
--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel

--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] How to get the buffer of current evas

2011-06-21 Thread suxia li
is there any way to get the data?

--- Original Message ---
Sender : Vincent Torrivto...@univ-evry.fr 
Date   : 六月 21, 2011 15:49 (GMT+09:00)
Title  : Re: [E-devel] How to get the buffer of current evas



On Tue, 21 Jun 2011, Atton Jonathan wrote:

 Evas is optimized, now Evas does not use a buffer. Data are in the cloud !

but he is using the buffer engine with ecore_evas, so it should work. 
Maybe a small test case would be helpful

Vincent


 2011/6/21 suxia li suxia...@samsung.com



 Hi,
  Here i want to get the buffer of current evas, so i tried by the 2 API ,
 firstly get the ecore evas, then get the buffer pixels of current
 Ecore_Evas, but the second API return NULL. is there any one help me on this
 issue, thanks in advance.

 ecore_evas_ecore_evas_get??const Evas *e
 ecore_evas_buffer_pixels_get??Ecore_Evas *ee

 Best Regards

 --
 EditLive Enterprise is the world's most technically advanced content
 authoring tool. Experience the power of Track Changes, Inline Image
 Editing and ensure content is compliant with Accessibility Checking.
 http://p.sf.net/sfu/ephox-dev2dev
 ___
 enlightenment-devel mailing list
 enlightenment-devel@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-devel




 -- 
 Regards.
 --
 EditLive Enterprise is the world's most technically advanced content
 authoring tool. Experience the power of Track Changes, Inline Image
 Editing and ensure content is compliant with Accessibility Checking.
 http://p.sf.net/sfu/ephox-dev2dev
 ___
 enlightenment-devel mailing list
 enlightenment-devel@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


pnbsp;/ppnbsp;/p
--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] How to get the buffer of current evas

2011-06-21 Thread Vincent Torri



On Tue, 21 Jun 2011, suxia li wrote:


is there any way to get the data?


with the buffer engine of ecore_evas. Did you write a small test ?

Vincent



--- Original Message ---
Sender : Vincent Torrivto...@univ-evry.fr
Date   : 六月 21, 2011 15:49 (GMT+09:00)
Title  : Re: [E-devel] How to get the buffer of current evas



On Tue, 21 Jun 2011, Atton Jonathan wrote:


Evas is optimized, now Evas does not use a buffer. Data are in the cloud !


but he is using the buffer engine with ecore_evas, so it should work.
Maybe a small test case would be helpful

Vincent



2011/6/21 suxia li suxia...@samsung.com




Hi,
 Here i want to get the buffer of current evas, so i tried by the 2 API ,
firstly get the ecore evas, then get the buffer pixels of current
Ecore_Evas, but the second API return NULL. is there any one help me on this
issue, thanks in advance.

ecore_evas_ecore_evas_get??const Evas *e
ecore_evas_buffer_pixels_get??Ecore_Evas *ee

Best Regards

--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel





--
Regards.
--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel



pnbsp;/ppnbsp;/p

--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] How to get the buffer of current evas

2011-06-21 Thread suxia li
oh, it use software_x11 engine, but i want to get the engine pixels(the buffer 
data of the canvas), do you know how to?

--- Original Message ---
Sender : Vincent Torrivto...@univ-evry.fr 
Date   : 六月 21, 2011 16:01 (GMT+09:00)
Title  : Re: Re: [E-devel] How to get the buffer of current evas



On Tue, 21 Jun 2011, suxia li wrote:

 is there any way to get the data?

with the buffer engine of ecore_evas. Did you write a small test ?

Vincent


 --- Original Message ---
 Sender : Vincent Torrivto...@univ-evry.fr
 Date   : 六月 21, 2011 15:49 (GMT+09:00)
 Title  : Re: [E-devel] How to get the buffer of current evas



 On Tue, 21 Jun 2011, Atton Jonathan wrote:

 Evas is optimized, now Evas does not use a buffer. Data are in the cloud !

 but he is using the buffer engine with ecore_evas, so it should work.
 Maybe a small test case would be helpful

 Vincent


 2011/6/21 suxia li suxia...@samsung.com



 Hi,
  Here i want to get the buffer of current evas, so i tried by the 2 API ,
 firstly get the ecore evas, then get the buffer pixels of current
 Ecore_Evas, but the second API return NULL. is there any one help me on this
 issue, thanks in advance.

 ecore_evas_ecore_evas_get??const Evas *e
 ecore_evas_buffer_pixels_get??Ecore_Evas *ee

 Best Regards

 --
 EditLive Enterprise is the world's most technically advanced content
 authoring tool. Experience the power of Track Changes, Inline Image
 Editing and ensure content is compliant with Accessibility Checking.
 http://p.sf.net/sfu/ephox-dev2dev
 ___
 enlightenment-devel mailing list
 enlightenment-devel@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-devel




 --
 Regards.
 --
 EditLive Enterprise is the world's most technically advanced content
 authoring tool. Experience the power of Track Changes, Inline Image
 Editing and ensure content is compliant with Accessibility Checking.
 http://p.sf.net/sfu/ephox-dev2dev
 ___
 enlightenment-devel mailing list
 enlightenment-devel@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


 pnbsp;/ppnbsp;/p


pnbsp;/ppnbsp;/p
--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] How to get the buffer of current evas

2011-06-21 Thread Vincent Torri



On Tue, 21 Jun 2011, suxia li wrote:


oh, it use software_x11 engine, but i want to get the engine pixels(the buffer 
data of the canvas), do you know how to?


what do you want to do, exactly ?

Vincent



--- Original Message ---
Sender : Vincent Torrivto...@univ-evry.fr
Date   : 六月 21, 2011 16:01 (GMT+09:00)
Title  : Re: Re: [E-devel] How to get the buffer of current evas



On Tue, 21 Jun 2011, suxia li wrote:


is there any way to get the data?


with the buffer engine of ecore_evas. Did you write a small test ?

Vincent



--- Original Message ---
Sender : Vincent Torrivto...@univ-evry.fr
Date   : 六月 21, 2011 15:49 (GMT+09:00)
Title  : Re: [E-devel] How to get the buffer of current evas



On Tue, 21 Jun 2011, Atton Jonathan wrote:


Evas is optimized, now Evas does not use a buffer. Data are in the cloud !


but he is using the buffer engine with ecore_evas, so it should work.
Maybe a small test case would be helpful

Vincent



2011/6/21 suxia li suxia...@samsung.com




Hi,
 Here i want to get the buffer of current evas, so i tried by the 2 API ,
firstly get the ecore evas, then get the buffer pixels of current
Ecore_Evas, but the second API return NULL. is there any one help me on this
issue, thanks in advance.

ecore_evas_ecore_evas_get??const Evas *e
ecore_evas_buffer_pixels_get??Ecore_Evas *ee

Best Regards

--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel





--
Regards.
--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel



pnbsp;/ppnbsp;/p



pnbsp;/ppnbsp;/p

--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] How to get the buffer of current evas

2011-06-21 Thread suxia li
i want to get the current screen data,  and set it to an evas object image.

--- Original Message ---
Sender : Vincent Torrivto...@univ-evry.fr 
Date   : 六月 21, 2011 16:50 (GMT+09:00)
Title  : Re: Re: Re: [E-devel] How to get the buffer of current evas



On Tue, 21 Jun 2011, suxia li wrote:

 oh, it use software_x11 engine, but i want to get the engine pixels(the 
 buffer data of the canvas), do you know how to?

what do you want to do, exactly ?

Vincent


 --- Original Message ---
 Sender : Vincent Torrivto...@univ-evry.fr
 Date   : 六月 21, 2011 16:01 (GMT+09:00)
 Title  : Re: Re: [E-devel] How to get the buffer of current evas



 On Tue, 21 Jun 2011, suxia li wrote:

 is there any way to get the data?

 with the buffer engine of ecore_evas. Did you write a small test ?

 Vincent


 --- Original Message ---
 Sender : Vincent Torrivto...@univ-evry.fr
 Date   : 六月 21, 2011 15:49 (GMT+09:00)
 Title  : Re: [E-devel] How to get the buffer of current evas



 On Tue, 21 Jun 2011, Atton Jonathan wrote:

 Evas is optimized, now Evas does not use a buffer. Data are in the cloud !

 but he is using the buffer engine with ecore_evas, so it should work.
 Maybe a small test case would be helpful

 Vincent


 2011/6/21 suxia li suxia...@samsung.com



 Hi,
  Here i want to get the buffer of current evas, so i tried by the 2 API ,
 firstly get the ecore evas, then get the buffer pixels of current
 Ecore_Evas, but the second API return NULL. is there any one help me on 
 this
 issue, thanks in advance.

 ecore_evas_ecore_evas_get??const Evas *e
 ecore_evas_buffer_pixels_get??Ecore_Evas *ee

 Best Regards

 --
 EditLive Enterprise is the world's most technically advanced content
 authoring tool. Experience the power of Track Changes, Inline Image
 Editing and ensure content is compliant with Accessibility Checking.
 http://p.sf.net/sfu/ephox-dev2dev
 ___
 enlightenment-devel mailing list
 enlightenment-devel@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-devel




 --
 Regards.
 --
 EditLive Enterprise is the world's most technically advanced content
 authoring tool. Experience the power of Track Changes, Inline Image
 Editing and ensure content is compliant with Accessibility Checking.
 http://p.sf.net/sfu/ephox-dev2dev
 ___
 enlightenment-devel mailing list
 enlightenment-devel@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


 pnbsp;/ppnbsp;/p


 pnbsp;/ppnbsp;/p


pnbsp;/ppnbsp;/p
--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] about removing trailing whitespaces

2011-06-21 Thread Thomas Gstädtner
On Sun, Jun 19, 2011 at 12:50, Albin Tonnerre albin.tonne...@gmail.com wrote:
 On Sun, 19 Jun 2011 12:38 +0200, Vincent Torri wrote :

 Hey

 another idea about trailing whitespaces : what about adding a rule in the
 toplevel Makefile.am, named for example remove-ws, that call find with a
 sed expression.

 I'll add it to Evil and test it a bit, and if nobody complains, i'll add
 it to the EFL + e.

 While it is nice to get rid of trailing whitespaces, I think that actively
 removing them periodically does more harm than good. In particular, it adds a
 lot of noise in the history and makes it harder to compare different 
 revisions.

 If we indeed want to get rid of them, I'd be much happier if the SVN server
 simply rejected commits containing them (the same holds true for formatting -
 it's much better to ask people to submit properly formatted patches rather 
 than
 going on a reformatting spree every now and then)

 Cheers,
 --
 Albin Tonnerre


I think putting this in a Makefile is a bad idea.
Alternative: how about using a pre-commit hook in SVN that either
removes whitespaces right away and sends a SPANK SPANK SPANK mail to
the evil dev who did it, or just rejects the patch as Albin suggested.
The first way is more proactive and should keep the commit/history
clean.

--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] How to get the buffer of current evas

2011-06-21 Thread Nicolas Aguirre
2011/6/21 suxia li suxia...@samsung.com:


 Hi,
  Here i want to get the buffer of current evas, so i tried by the 2 API , 
 firstly get the ecore evas, then get the buffer pixels of current Ecore_Evas, 
 but the second API return NULL. is there any one help me on this issue, 
 thanks in advance.

 ecore_evas_ecore_evas_get(const Evas *e);

This function get the ecore_evas associated to an Evas ?

 ecore_evas_buffer_pixels_get(Ecore_Evas *ee);

I think that this function is for buffer engine only. IIRC it's what
is used for ethumb for example to generate thumbnail, you create un
evas buffer ans then you add you evas object, and finally you get
pixels of this bufffer engine to write back images on disk. But it's
only with engine buffer.

A way to do what you want, is using ecore_x function to get the whole
window content, as the E17 shot module do for the root window.
ecore_x_image_get and ecore_x_image_date_get might do what you want.

Maybe a better solution exists ? Guys other ideas ?



 Best Regards
 --
 EditLive Enterprise is the world's most technically advanced content
 authoring tool. Experience the power of Track Changes, Inline Image
 Editing and ensure content is compliant with Accessibility Checking.
 http://p.sf.net/sfu/ephox-dev2dev
 ___
 enlightenment-devel mailing list
 enlightenment-devel@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-devel




-- 
Nicolas Aguirre
Mail: aguirre.nico...@gmail.com
Web: http://enna.geexbox.org
Blog: http://dev.enlightenment.fr/~captainigloo/

--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] How to get the buffer of current evas

2011-06-21 Thread The Rasterman
On Tue, 21 Jun 2011 07:53:51 + (GMT) suxia li suxia...@samsung.com said:

basically, you can't. the data may not exist in any gettable form. it may be in
1bit monochrome, in greyscale, in rgb or rgba - it's totally abstracted and the
buffer may simply not exist. in fact this is the case with all engines except
for buffer. evas allocs tmp update buffers, renders updates and pushes them to
the screen and then throws them out. it doesn't keep them. they no longer exist.

as such the fact that u are trying to grab the canvas buffer already tells me
you are probably doing something wrong as this is highly rare you want to do
this and if you do a grab.. it can't be updated as the grab is static, so if the
canvas is animating your grab stays still. it destroys the abstraction and
update paths to do this kind of thing. there are things like proxy objects
(image objects with source SET to another object that allow copies o that
object and all its contents to be put somewhere else on screen and even get
live updates from the original).


 i want to get the current screen data,  and set it to an evas object image.
 
 --- Original Message ---
 Sender : Vincent Torrivto...@univ-evry.fr 
 Date   : 六月 21, 2011 16:50 (GMT+09:00)
 Title  : Re: Re: Re: [E-devel] How to get the buffer of current evas
 
 
 
 On Tue, 21 Jun 2011, suxia li wrote:
 
  oh, it use software_x11 engine, but i want to get the engine pixels(the
  buffer data of the canvas), do you know how to?
 
 what do you want to do, exactly ?
 
 Vincent
 
 
  --- Original Message ---
  Sender : Vincent Torrivto...@univ-evry.fr
  Date   : 六月 21, 2011 16:01 (GMT+09:00)
  Title  : Re: Re: [E-devel] How to get the buffer of current evas
 
 
 
  On Tue, 21 Jun 2011, suxia li wrote:
 
  is there any way to get the data?
 
  with the buffer engine of ecore_evas. Did you write a small test ?
 
  Vincent
 
 
  --- Original Message ---
  Sender : Vincent Torrivto...@univ-evry.fr
  Date   : 六月 21, 2011 15:49 (GMT+09:00)
  Title  : Re: [E-devel] How to get the buffer of current evas
 
 
 
  On Tue, 21 Jun 2011, Atton Jonathan wrote:
 
  Evas is optimized, now Evas does not use a buffer. Data are in the cloud !
 
  but he is using the buffer engine with ecore_evas, so it should work.
  Maybe a small test case would be helpful
 
  Vincent
 
 
  2011/6/21 suxia li suxia...@samsung.com
 
 
 
  Hi,
   Here i want to get the buffer of current evas, so i tried by the 2 API ,
  firstly get the ecore evas, then get the buffer pixels of current
  Ecore_Evas, but the second API return NULL. is there any one help me on
  this issue, thanks in advance.
 
  ecore_evas_ecore_evas_get??const Evas *e
  ecore_evas_buffer_pixels_get??Ecore_Evas *ee
 
  Best Regards
 
  --
  EditLive Enterprise is the world's most technically advanced content
  authoring tool. Experience the power of Track Changes, Inline Image
  Editing and ensure content is compliant with Accessibility Checking.
  http://p.sf.net/sfu/ephox-dev2dev
  ___
  enlightenment-devel mailing list
  enlightenment-devel@lists.sourceforge.net
  https://lists.sourceforge.net/lists/listinfo/enlightenment-devel
 
 
 
 
  --
  Regards.
  --
  EditLive Enterprise is the world's most technically advanced content
  authoring tool. Experience the power of Track Changes, Inline Image
  Editing and ensure content is compliant with Accessibility Checking.
  http://p.sf.net/sfu/ephox-dev2dev
  ___
  enlightenment-devel mailing list
  enlightenment-devel@lists.sourceforge.net
  https://lists.sourceforge.net/lists/listinfo/enlightenment-devel
 
 
  pnbsp;/ppnbsp;/p
 
 
  pnbsp;/ppnbsp;/p
 
 
 pnbsp;/ppnbsp;/p
 --
 EditLive Enterprise is the world's most technically advanced content
 authoring tool. Experience the power of Track Changes, Inline Image
 Editing and ensure content is compliant with Accessibility Checking.
 http://p.sf.net/sfu/ephox-dev2dev
 ___
 enlightenment-devel mailing list
 enlightenment-devel@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


-- 
- Codito, ergo sum - I code, therefore I am --
The Rasterman (Carsten Haitzler)ras...@rasterman.com


--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list

Re: [E-devel] about removing trailing whitespaces

2011-06-21 Thread Vincent Torri



On Tue, 21 Jun 2011, Thomas Gstädtner wrote:


On Sun, Jun 19, 2011 at 12:50, Albin Tonnerre albin.tonne...@gmail.com wrote:

On Sun, 19 Jun 2011 12:38 +0200, Vincent Torri wrote :


Hey

another idea about trailing whitespaces : what about adding a rule in the
toplevel Makefile.am, named for example remove-ws, that call find with a
sed expression.

I'll add it to Evil and test it a bit, and if nobody complains, i'll add
it to the EFL + e.


While it is nice to get rid of trailing whitespaces, I think that actively
removing them periodically does more harm than good. In particular, it adds a
lot of noise in the history and makes it harder to compare different revisions.

If we indeed want to get rid of them, I'd be much happier if the SVN server
simply rejected commits containing them (the same holds true for formatting -
it's much better to ask people to submit properly formatted patches rather than
going on a reformatting spree every now and then)

Cheers,
--
Albin Tonnerre



I think putting this in a Makefile is a bad idea.
Alternative: how about using a pre-commit hook in SVN that either
removes whitespaces right away and sends a SPANK SPANK SPANK mail to
the evil dev who did it, or just rejects the patch as Albin suggested.
The first way is more proactive and should keep the commit/history
clean.


then, you will have huge chances to have conflicts if you want to update a 
file that you changed in your repo and that has been modified in your back 
by that prehook, right ?


Vincent Torri--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] e17 todo list - clock+calendar thing done

2011-06-21 Thread Thomas Gstädtner
On Tue, Jun 21, 2011 at 00:01, Carsten Haitzler ras...@rasterman.com wrote:
 On Mon, 20 Jun 2011 19:37:50 +0200 Cedric BAIL cedric.b...@free.fr said:

 On Mon, Jun 20, 2011 at 6:26 PM, Eduardo Lima (Etrunko)
 ebl...@gmail.com wrote:
  On Mon, Jun 20, 2011 at 1:23 PM, Eduardo Lima (Etrunko)
  ebl...@gmail.com wrote:
  Hmm. I found a weird behavior with the clock after noon and 24h mode.
  Screenshot attached:
 
 
  Damn, hit the send button too fast. Forgot to add that it happens only
  at when you click on the clock and the popup shows. The next update of
  the clock it will display the time correctly.

 Yes, it seems like hour are not updated correctly the first time.
 That's another bug not related to the wrong one we repported this
 morning (or maybe that was yesterday afternoon for Raster).

 as i keep saying.. i can't reproduce it. it's workign fine here.

 --
 - Codito, ergo sum - I code, therefore I am --
 The Rasterman (Carsten Haitzler)    ras...@rasterman.com


The wrong-hour bug is easily reproducable. Use systemclock with UTC +
local timezone, turn off seconds display, turn on digital 24h clock
(it only affects digital 24h) and open the calendar-popup. It will
show UTC, not localtime, while the main clock will show localtime.
Turn on seconds display, it will show UTC on the popup again, but
after 1 sec, when the clock gets updated the hour gets set to
localtime.
It also affects the main clock (not popup) itself, but of course only
after a E (re)start.

I did take a quick look at the code, but didn't find the reason.
Though you know the implementation and will probably spot it right on.
The reason certainly has to be the timezone-difference that's
calculated after updates, not at load time.

--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] about removing trailing whitespaces

2011-06-21 Thread Thomas Gstädtner
On Tue, Jun 21, 2011 at 11:56, Vincent Torri vto...@univ-evry.fr wrote:


 On Tue, 21 Jun 2011, Thomas Gstädtner wrote:

 On Sun, Jun 19, 2011 at 12:50, Albin Tonnerre albin.tonne...@gmail.com
 wrote:

 On Sun, 19 Jun 2011 12:38 +0200, Vincent Torri wrote :

 Hey

 another idea about trailing whitespaces : what about adding a rule in
 the
 toplevel Makefile.am, named for example remove-ws, that call find with a
 sed expression.

 I'll add it to Evil and test it a bit, and if nobody complains, i'll add
 it to the EFL + e.

 While it is nice to get rid of trailing whitespaces, I think that
 actively
 removing them periodically does more harm than good. In particular, it
 adds a
 lot of noise in the history and makes it harder to compare different
 revisions.

 If we indeed want to get rid of them, I'd be much happier if the SVN
 server
 simply rejected commits containing them (the same holds true for
 formatting -
 it's much better to ask people to submit properly formatted patches
 rather than
 going on a reformatting spree every now and then)

 Cheers,
 --
 Albin Tonnerre


 I think putting this in a Makefile is a bad idea.
 Alternative: how about using a pre-commit hook in SVN that either
 removes whitespaces right away and sends a SPANK SPANK SPANK mail to
 the evil dev who did it, or just rejects the patch as Albin suggested.
 The first way is more proactive and should keep the commit/history
 clean.

 then, you will have huge chances to have conflicts if you want to update a
 file that you changed in your repo and that has been modified in your back
 by that prehook, right ?

 Vincent Torri

That is true, but the Don't do that, nasty programmer. SPANK SPANK
SPANK mail tells you that the hook triggered and also it hurts the
programmer who did produce the trailing whitespaces. People learn best
when it hurts :P
It certainly is a rather harsh method to enforce this policy but it
certainly would keep this out.
(Of course pre-commit hooks always hurt, that's what they are for and
that's why they should be used really sparsely).
Also people having to clean their personal repos seems to be more
desirable than having trivial commits to remove that stuff in the
public history.

--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] about removing trailing whitespaces

2011-06-21 Thread David Seikel
On Tue, 21 Jun 2011 13:43:13 +0200 Thomas Gstädtner
tho...@gstaedtner.net wrote:

 That is true, but the Don't do that, nasty programmer. SPANK SPANK
 SPANK mail tells you that the hook triggered and also it hurts the
 programmer who did produce the trailing whitespaces. People learn best
 when it hurts :P

Automated emails might just go to spam, don't hurt that much.  Unless
you intend to not accept the commit and make them do it over.  That
will hurt enough.

-- 
A big old stinking pile of genius that no one wants
coz there are too many silver coated monkeys in the world.


signature.asc
Description: PGP signature
--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


[E-devel] [PATCH] elm_diskselector has mistypo APIs

2011-06-21 Thread Jihoon Kim
Hi,

In some elm_diskselector API and doxygen, there are simple typographical
errors.
This patch will fix it.
Index: Elementary.h.in
===
--- Elementary.h.in	(리비전 60547)
+++ Elementary.h.in	(작업 사본)
@@ -4158,8 +4158,8 @@ EAPI Elm_Genlist_Item *elm_genlist_item_sorted_ins
EAPI Evas_Object   *elm_diskselector_add(Evas_Object *parent) EINA_ARG_NONNULL(1);
EAPI Eina_Bool  elm_diskselector_round_get(const Evas_Object *obj) EINA_ARG_NONNULL(1);
EAPI void   elm_diskselector_round_set(Evas_Object *obj, Eina_Bool round) EINA_ARG_NONNULL(1);
-   EAPI intelm_diskselector_side_label_lenght_get(const Evas_Object *obj) EINA_ARG_NONNULL(1);
-   EAPI void   elm_diskselector_side_label_lenght_set(Evas_Object *obj, int len) EINA_ARG_NONNULL(1);
+   EAPI intelm_diskselector_side_label_length_get(const Evas_Object *obj) EINA_ARG_NONNULL(1);
+   EAPI void   elm_diskselector_side_label_length_set(Evas_Object *obj, int len) EINA_ARG_NONNULL(1);
EAPI void   elm_diskselector_bounce_set(Evas_Object *obj, Eina_Bool h_bounce, Eina_Bool v_bounce) EINA_ARG_NONNULL(1);
EAPI void   elm_diskselector_bounce_get(const Evas_Object *obj, Eina_Bool *h_bounce, Eina_Bool *v_bounce) EINA_ARG_NONNULL(1);
EAPI void   elm_diskselector_scroller_policy_get(const Evas_Object *obj, Elm_Scroller_Policy *policy_h, Elm_Scroller_Policy *policy_v) EINA_ARG_NONNULL(1);
--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: devilhorns trunk/e/src/modules/illume-keyboard/keyboards

2011-06-21 Thread Christopher Michael
How was it not the right fix ? The images themselves were white, being 
displayed on white buttons.

dh

On 06/21/2011 06:18 AM, michael bouchaud wrote:
 Hum ... I don't think this was the right fix

 2011/6/20 Enlightenment SVNno-re...@enlightenment.org

 Log:
 Illume Keyboard: Fix incorrect white images.



 Author:   devilhorns
 Date: 2011-06-20 14:31:51 -0700 (Mon, 20 Jun 2011)
 New Revision: 60536
 Trac: http://trac.enlightenment.org/e/changeset/60536

 Modified:
   trunk/e/src/modules/illume-keyboard/keyboards/backspace.png
 trunk/e/src/modules/illume-keyboard/keyboards/down.png
 trunk/e/src/modules/illume-keyboard/keyboards/enter.png
 trunk/e/src/modules/illume-keyboard/keyboards/left.png
 trunk/e/src/modules/illume-keyboard/keyboards/right.png
 trunk/e/src/modules/illume-keyboard/keyboards/shift.png
 trunk/e/src/modules/illume-keyboard/keyboards/tab.png
 trunk/e/src/modules/illume-keyboard/keyboards/up.png

 Modified: trunk/e/src/modules/illume-keyboard/keyboards/backspace.png
 ===
 (Binary files differ)

 Modified: trunk/e/src/modules/illume-keyboard/keyboards/down.png
 ===
 (Binary files differ)

 Modified: trunk/e/src/modules/illume-keyboard/keyboards/enter.png
 ===
 (Binary files differ)

 Modified: trunk/e/src/modules/illume-keyboard/keyboards/left.png
 ===
 (Binary files differ)

 Modified: trunk/e/src/modules/illume-keyboard/keyboards/right.png
 ===
 (Binary files differ)

 Modified: trunk/e/src/modules/illume-keyboard/keyboards/shift.png
 ===
 (Binary files differ)

 Modified: trunk/e/src/modules/illume-keyboard/keyboards/tab.png
 ===
 (Binary files differ)

 Modified: trunk/e/src/modules/illume-keyboard/keyboards/up.png
 ===
 (Binary files differ)



 --
 EditLive Enterprise is the world's most technically advanced content
 authoring tool. Experience the power of Track Changes, Inline Image
 Editing and ensure content is compliant with Accessibility Checking.
 http://p.sf.net/sfu/ephox-dev2dev
 ___
 enlightenment-svn mailing list
 enlightenment-...@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-svn






--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: devilhorns trunk/e/src/modules/illume-keyboard/keyboards

2011-06-21 Thread Christopher Michael
Ohhh I see now. It was the 'clip on a rect' thing. Thanks for the fix :)

dh

On 06/21/2011 09:31 AM, Christopher Michael wrote:
 How was it not the right fix ? The images themselves were white, being
 displayed on white buttons.

 dh

 On 06/21/2011 06:18 AM, michael bouchaud wrote:
 Hum ... I don't think this was the right fix

 2011/6/20 Enlightenment SVNno-re...@enlightenment.org

 Log:
 Illume Keyboard: Fix incorrect white images.



 Author:   devilhorns
 Date: 2011-06-20 14:31:51 -0700 (Mon, 20 Jun 2011)
 New Revision: 60536
 Trac: http://trac.enlightenment.org/e/changeset/60536

 Modified:
trunk/e/src/modules/illume-keyboard/keyboards/backspace.png
 trunk/e/src/modules/illume-keyboard/keyboards/down.png
 trunk/e/src/modules/illume-keyboard/keyboards/enter.png
 trunk/e/src/modules/illume-keyboard/keyboards/left.png
 trunk/e/src/modules/illume-keyboard/keyboards/right.png
 trunk/e/src/modules/illume-keyboard/keyboards/shift.png
 trunk/e/src/modules/illume-keyboard/keyboards/tab.png
 trunk/e/src/modules/illume-keyboard/keyboards/up.png

 Modified: trunk/e/src/modules/illume-keyboard/keyboards/backspace.png
 ===
 (Binary files differ)

 Modified: trunk/e/src/modules/illume-keyboard/keyboards/down.png
 ===
 (Binary files differ)

 Modified: trunk/e/src/modules/illume-keyboard/keyboards/enter.png
 ===
 (Binary files differ)

 Modified: trunk/e/src/modules/illume-keyboard/keyboards/left.png
 ===
 (Binary files differ)

 Modified: trunk/e/src/modules/illume-keyboard/keyboards/right.png
 ===
 (Binary files differ)

 Modified: trunk/e/src/modules/illume-keyboard/keyboards/shift.png
 ===
 (Binary files differ)

 Modified: trunk/e/src/modules/illume-keyboard/keyboards/tab.png
 ===
 (Binary files differ)

 Modified: trunk/e/src/modules/illume-keyboard/keyboards/up.png
 ===
 (Binary files differ)



 --
 EditLive Enterprise is the world's most technically advanced content
 authoring tool. Experience the power of Track Changes, Inline Image
 Editing and ensure content is compliant with Accessibility Checking.
 http://p.sf.net/sfu/ephox-dev2dev
 ___
 enlightenment-svn mailing list
 enlightenment-...@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-svn






 --
 EditLive Enterprise is the world's most technically advanced content
 authoring tool. Experience the power of Track Changes, Inline Image
 Editing and ensure content is compliant with Accessibility Checking.
 http://p.sf.net/sfu/ephox-dev2dev
 ___
 enlightenment-devel mailing list
 enlightenment-devel@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-devel



--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: raster trunk/e/data/themes

2011-06-21 Thread Boris Faure
On Tue, Jun 21, 2011 at 15:03, Enlightenment SVN
no-re...@enlightenment.org wrote:
 Log:
 hmm maybe its a signal queue ordering thing  - clock state. try this.

That fixes the issue I had with the clock showing UTC hour before
getting refreshed.
Thank you.
-- 
Boris Faure

--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] Segfault when starting e17 (evas module)

2011-06-21 Thread The Rasterman
On Tue, 21 Jun 2011 15:28:01 +0200 Svante Signell svante.sign...@telia.com
said:

 On Sat, 2011-06-18 at 08:42 +0900, Carsten Haitzler wrote:
  On Fri, 17 Jun 2011 16:38:48 +0200 Svante Signell svante.sign...@telia.com
  said:
 ...
   A full backtrace, see http://paste.debian.net/120170/ shows that
   something goes wrong within the function
   scale_rgba_in_to_out_clip_sample_internal()
   
   #0: evas_scale_sample.c:284 at
   scale_rgba_in_to_out_clip_sample_internal() 
   Arguments: src_region_h=80, dst_region_h=768
   Local variables: src_h = 31439232, dst_h = 9584648  Totally wrong
  
  and yes - totally wrong. also there is code to protect against nutty
  dimensions like this... so i'm wondering if this is stack corruption?
 
 Thank you for your help so far. I have now compiled and installed evas
 1.0.1 and eina 1.0.1, the problem remains. How to debug a stack
 corruption? Valgrind is unfortunately not available.

well stack corruption happens because of a bug. the only way is either valgrind
(even that can only help a bit for tack corruption), OR... you literally trap,
and step bit by bit until u get to the known bug point and print stacks along
the way until it goes weird. no valgrind makes your life a lot harder.


-- 
- Codito, ergo sum - I code, therefore I am --
The Rasterman (Carsten Haitzler)ras...@rasterman.com


--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: devilhorns trunk/e/src/modules/illume-keyboard/keyboards

2011-06-21 Thread David Seikel
On Tue, 21 Jun 2011 09:31:39 -0400 Christopher Michael
cpmicha...@comcast.net wrote:

 How was it not the right fix ? The images themselves were white,
 being displayed on white buttons.

Did they light up white when you click them, and say Don't do that
again.?

Oh wait, that's the black buttons.

-- 
A big old stinking pile of genius that no one wants
coz there are too many silver coated monkeys in the world.


signature.asc
Description: PGP signature
--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] [PATCH] elementary doxygen patch

2011-06-21 Thread Gustavo Lima Chaves
* Jihoon Kim imfin...@gmail.com [2011-06-21 22:13:38 +0900]:

Hi, Jihoon.

I'm already addressing these functions' documentation, so you'll get them
with the right types in a moment.

BR,

 Hello,
 
 In doxygen of elementary API, I use EINA_TRUE or EINA_FALSE instead of 1 or
 0.
 Would you please apply this simple patch?

 Index: elm_main.c
 ===
 --- elm_main.c(리비전 60547)
 +++ elm_main.c(작업 사본)
 @@ -2377,7 +2377,7 @@ elm_edje_collection_cache_all_set(int size)
   * This gets the focused property of the object.
   *
   * @param obj The object
 - * @return 1 if the object is focused, 0 if not.
 + * @return EINA_TRUE if the object is focused, EINA_FALSE if not.
   * @ingroup Focus
   */
  EAPI Eina_Bool
 @@ -2429,7 +2429,7 @@ elm_object_unfocus(Evas_Object *obj)
   * not. By default all objects are able to be focused.
   *
   * @param obj The object
 - * @param enable 1 if the object can be focused, 0 if not
 + * @param enable EINA_TRUE if the object can be focused, EINA_FALSE if not
   * @ingroup Focus
   */
  EAPI void
 @@ -2447,7 +2447,7 @@ elm_object_focus_allow_set(Evas_Object *obj,
   * not. By default all objects are able to be focused.
   *
   * @param obj The object
 - * @return 1 if the object is allowed to be focused, 0 if not.
 + * @return EINA_TRUE if the object is allowed to be focused, EINA_FALSE if 
 not.
   * @ingroup Focus
   */
  EAPI Eina_Bool

 --
 EditLive Enterprise is the world's most technically advanced content
 authoring tool. Experience the power of Track Changes, Inline Image
 Editing and ensure content is compliant with Accessibility Checking.
 http://p.sf.net/sfu/ephox-dev2dev

 ___
 enlightenment-devel mailing list
 enlightenment-devel@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


-- 
Gustavo Lima Chaves
Computer Engineer @ ProFUSION Embedded Systems

--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: raster trunk/e/src/modules/battery

2011-06-21 Thread The Rasterman
On Tue, 21 Jun 2011 17:29:49 -0400 Mike Blumenkrantz m...@zentific.com said:

 On Tue, 21 Jun 2011 06:34:52 -0700
 Enlightenment SVN no-re...@enlightenment.org wrote:
 
  Log:
  jeff - try this battery change


  
  Author:   raster
  Date: 2011-06-21 06:34:52 -0700 (Tue, 21 Jun 2011)
  New Revision: 60549
  Trac: http://trac.enlightenment.org/e/changeset/60549
  
 still getting that udev crash?

i havent seen one recently.

-- 
- Codito, ergo sum - I code, therefore I am --
The Rasterman (Carsten Haitzler)ras...@rasterman.com


--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] e17 todo list - clock+calendar thing done

2011-06-21 Thread The Rasterman
On Tue, 21 Jun 2011 01:16:10 -0300 Lucas De Marchi
lucas.demar...@profusion.mobi said:

try now.

 On Tue, Jun 21, 2011 at 1:14 AM, Lucas De Marchi
 lucas.demar...@profusion.mobi wrote:
  On Mon, Jun 20, 2011 at 7:01 PM, Carsten Haitzler ras...@rasterman.com
  wrote:
 
  as i keep saying.. i can't reproduce it. it's workign fine here.
 
  Did you put it in 24h mode and looked at it *after* 20h?
 
 I should have written *after* 13h, not 20h
 
 Lucas De Marchi
 
 --
 EditLive Enterprise is the world's most technically advanced content
 authoring tool. Experience the power of Track Changes, Inline Image
 Editing and ensure content is compliant with Accessibility Checking.
 http://p.sf.net/sfu/ephox-dev2dev
 ___
 enlightenment-devel mailing list
 enlightenment-devel@lists.sourceforge.net
 https://lists.sourceforge.net/lists/listinfo/enlightenment-devel
 


-- 
- Codito, ergo sum - I code, therefore I am --
The Rasterman (Carsten Haitzler)ras...@rasterman.com


--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: raster trunk/e/data/themes

2011-06-21 Thread The Rasterman
On Tue, 21 Jun 2011 15:39:58 +0200 Boris Faure bill...@gmail.com said:

 On Tue, Jun 21, 2011 at 15:03, Enlightenment SVN
 no-re...@enlightenment.org wrote:
  Log:
  hmm maybe its a signal queue ordering thing  - clock state. try this.
 
 That fixes the issue I had with the clock showing UTC hour before
 getting refreshed.
 Thank you.

yay

-- 
- Codito, ergo sum - I code, therefore I am --
The Rasterman (Carsten Haitzler)ras...@rasterman.com


--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] [PATCH] elm_diskselector has mistypo APIs

2011-06-21 Thread Jihoon Kim
Oops, test_diskselector uses API I modified in the previous patch e-mail.

I also fix test_diskselector.c and send the patch.
Please apply this patch for building elementary without build error.

-Original Message-
From: Jihoon Kim [mailto:imfin...@gmail.com] 
Sent: Tuesday, June 21, 2011 10:21 PM
To: enlightenment-devel@lists.sourceforge.net
Subject: [E-devel] [PATCH] elm_diskselector has mistypo APIs

Hi,

In some elm_diskselector API and doxygen, there are simple typographical
errors.
This patch will fix it.



test_diskselector.patch
Description: Binary data
--
EditLive Enterprise is the world's most technically advanced content
authoring tool. Experience the power of Track Changes, Inline Image
Editing and ensure content is compliant with Accessibility Checking.
http://p.sf.net/sfu/ephox-dev2dev___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: raster trunk/e/data/themes

2011-06-21 Thread Thomas Gstädtner
On Wed, Jun 22, 2011 at 01:38, Carsten Haitzler ras...@rasterman.com wrote:
 On Tue, 21 Jun 2011 15:39:58 +0200 Boris Faure bill...@gmail.com said:

 On Tue, Jun 21, 2011 at 15:03, Enlightenment SVN
 no-re...@enlightenment.org wrote:
  Log:
  hmm maybe its a signal queue ordering thing  - clock state. try this.

 That fixes the issue I had with the clock showing UTC hour before
 getting refreshed.
 Thank you.

 yay

 --
 - Codito, ergo sum - I code, therefore I am --
 The Rasterman (Carsten Haitzler)    ras...@rasterman.com

Works for me as well. Thanks a lot.

--
Simplify data backup and recovery for your virtual environment with vRanger.
Installation's a snap, and flexible recovery options mean your data is safe,
secure and there when you need it. Data protection magic?
Nope - It's vRanger. Get your free trial download today.
http://p.sf.net/sfu/quest-sfdev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] e17 todo list - clock+calendar thing done

2011-06-21 Thread Lucas De Marchi
On Tue, Jun 21, 2011 at 8:40 PM, Carsten Haitzler ras...@rasterman.com wrote:
 On Tue, 21 Jun 2011 01:16:10 -0300 Lucas De Marchi
 lucas.demar...@profusion.mobi said:

 try now.


It's working now, thanks;


Lucas De Marchi

--
Simplify data backup and recovery for your virtual environment with vRanger.
Installation's a snap, and flexible recovery options mean your data is safe,
secure and there when you need it. Data protection magic?
Nope - It's vRanger. Get your free trial download today.
http://p.sf.net/sfu/quest-sfdev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] [Patch][Evil] add some variables on evil_langinfo

2011-06-21 Thread cnook
Dear Mr. Vincent,

Thanks for your response.
Actually I refer to the previous version mingw-langinfo-0.1.
Anyhow why don't you use the reference tar ball as other dependent
modules(that is, libcurl, libgcrypt, and so on)?

Sincerely,
Shinwoo Kim.


2011/6/20 Vincent Torri vto...@univ-evry.fr


 Hey


 On Fri, 17 Jun 2011, cnook wrote:

  Dear All,

 Hello~
 I add some enumeration variables for building on Windows.

 And.. One question,
 nl_langinfo(CODESET) gives return value properly on MinGW?


 nl_langinfo is not defined on Windows. I never really tested that code...
 Note that there is a code in public domain here :

 http://snaury.narod.ru/mingw-**langinfo-0.1b.tar.bz2http://snaury.narod.ru/mingw-langinfo-0.1b.tar.bz2

 found in that mingw thread:

 http://comments.gmane.org/**gmane.comp.gnu.mingw.user/**16568http://comments.gmane.org/gmane.comp.gnu.mingw.user/16568

 maybe it can help

 cheers

 Vincent

--
Simplify data backup and recovery for your virtual environment with vRanger.
Installation's a snap, and flexible recovery options mean your data is safe,
secure and there when you need it. Data protection magic?
Nope - It's vRanger. Get your free trial download today.
http://p.sf.net/sfu/quest-sfdev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


[E-devel] [Patch][Evil] evil_string has strcasestr

2011-06-21 Thread cnook
Hi All,

There is no strcasestr() on MinGW Env.
So this patch comes.. Please review the attached one.

Sincerely,
Shinwoo Kim.
Index: src/lib/evil_string.c
===
--- src/lib/evil_string.c	(revision 60564)
+++ src/lib/evil_string.c	(working copy)
@@ -3,8 +3,8 @@
 #endif /* HAVE_CONFIG_H */
 
 #include Evil.h
+#include ctype.h
 
-
 #ifdef _WIN32_WCE
 
 /*
@@ -84,6 +84,31 @@
   return ret;
 }
 
+char *
+strcasestr (char *h, char *n)
+{
+   char *a, *e;
+   a = h;
+   e = n;
+
+   if (!h || !*h || !n ||!*n) return 0;
+   while (*a  *e)
+ {
+if(toupper((unsigned char) *a) != toupper((unsigned char) *e))
+  {
+ ++h;
+ a = h;
+ e = n;
+  }
+else
+  {
+ ++a;
+ ++e;
+  }
+ }
+   return *e ? 0 : h;
+} 
+
 #ifdef _MSC_VER
 
 int strcasecmp(const char *s1, const char *s2)
Index: src/lib/evil_string.h
===
--- src/lib/evil_string.h	(revision 60564)
+++ src/lib/evil_string.h	(working copy)
@@ -103,6 +103,11 @@
  */
 EAPI char *strrstr (const char *str, const char *substr);
 
+/**
+ * @brief Similar to 'strstr' but this function ignores the case of both strings. 
+ */
+EAPI char *strcasestr (char *str, char *substr);
+
 #ifdef _MSC_VER
 
 EAPI int strcasecmp(const char *s1, const char *s2);
Index: elm_diskselector.c
===
--- elm_diskselector.c	(리비전 60547)
+++ elm_diskselector.c	(작업 사본)
@@ -6,7 +6,7 @@
  * with the selected on the middle.
  *
  * It can act like a circular list with round mode and labels can be
  * reduced for a defined lenght for side items.
  *
  * Signals that you can add callbacks for are:
  *
@@ -948,16 +948,16 @@ elm_diskselector_round_set(Evas_Object * obj, Eina
 }
 
 /**
  * Get the side labels max lenght
  *
  * @param obj The diskselector object
  * @return The max lenght defined for side labels, or 0 if not a valid
  * diskselector
  *
  * @ingroup Diskselector
  */
 EAPI int
-elm_diskselector_side_label_lenght_get(const Evas_Object *obj)
+elm_diskselector_side_label_length_get(const Evas_Object *obj)
 {
ELM_CHECK_WIDTYPE(obj, widtype) 0;
Widget_Data *wd = elm_widget_data_get(obj);
@@ -966,15 +966,15 @@ EAPI int
 }
 
 /**
  * Set the side labels max lenght
  *
  * @param obj The diskselector object
  * @param len The max lenght defined for side labels
  *
  * @ingroup Diskselector
  */
 EAPI void
-elm_diskselector_side_label_lenght_set(Evas_Object *obj, int len)
+elm_diskselector_side_label_length_set(Evas_Object *obj, int len)
 {
@@ -6,7 +6,7 @@
  *
  * It can act like a circular list with round mode and labels can be
- * reduced for a defined lenght for side items.
+ * reduced for a defined length for side items.
  *
  * Signals that you can add callbacks for are:
@@ -948,16 +948,16 @@ elm_diskselector_round_set(Evas_Object * obj, Eina
 
 /**
- * Get the side labels max lenght
+ * Get the side labels max length
  *
  * @param obj The diskselector object
@@ -948,16 +948,16 @@ elm_diskselector_round_set(Evas_Object * obj, Eina
  *
  * @param obj The diskselector object
- * @return The max lenght defined for side labels, or 0 if not a valid
+ * @return The max length defined for side labels, or 0 if not a valid
  * diskselector
  *
@@ -966,15 +966,15 @@ EAPI int
 
 /**
- * Set the side labels max lenght
+ * Set the side labels max length
  *
  * @param obj The diskselector object
@@ -966,15 +966,15 @@ EAPI int
  *
  * @param obj The diskselector object
- * @param len The max lenght defined for side labels
+ * @param len The max length defined for side labels
  *
  * @ingroup Diskselector
ELM_CHECK_WIDTYPE(obj, widtype);
Widget_Data *wd = elm_widget_data_get(obj);
--
Simplify data backup and recovery for your virtual environment with vRanger.
Installation's a snap, and flexible recovery options mean your data is safe,
secure and there when you need it. Data protection magic?
Nope - It's vRanger. Get your free trial download today.
http://p.sf.net/sfu/quest-sfdev2dev___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] E SVN: devilhorns trunk/e/src/modules/illume-keyboard/keyboards

2011-06-21 Thread Jeff Hoogland
Are these buttons going to get fixed at some point? Just did an SVN
pull down this evening and still getting white images on white
buttons.

Fixing them myself before building for now - but would be nice to have
it fixed in the SVN.

~Jeff

On 6/21/11, David Seikel onef...@gmail.com wrote:
 On Tue, 21 Jun 2011 09:31:39 -0400 Christopher Michael
 cpmicha...@comcast.net wrote:

 How was it not the right fix ? The images themselves were white,
 being displayed on white buttons.

 Did they light up white when you click them, and say Don't do that
 again.?

 Oh wait, that's the black buttons.

 --
 A big old stinking pile of genius that no one wants
 coz there are too many silver coated monkeys in the world.


--
Simplify data backup and recovery for your virtual environment with vRanger.
Installation's a snap, and flexible recovery options mean your data is safe,
secure and there when you need it. Data protection magic?
Nope - It's vRanger. Get your free trial download today.
http://p.sf.net/sfu/quest-sfdev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] [PATCH] elm_diskselector has mistypo APIs

2011-06-21 Thread ChunEon Park
 
Thanks. Jihoon Kim
 
in svn
 
But kept the previous APis as DEPRECAETD. 
 
 
 

Let's run together for the best moment!
-Regards, Hermet-
 
-Original Message-
From: Jihoon Kimlt;jihoon48@samsung.comgt; 
To: enlightenment-devel@lists.sourceforge.net
Cc: 
Sent: 11-06-22(수) 08:44:42
Subject: Re: [E-devel] [PATCH] elm_diskselector has mistypo APIsOops, 
test_diskselector uses API I modified in the previous patch e-mail.
I also fix test_diskselector.c and send the patch.
Please apply this patch for building elementary without build error.
-Original Message-
From: Jihoon Kim [mailto:imfin...@gmail.com] 
Sent: Tuesday, June 21, 2011 10:21 PM
To: enlightenment-devel@lists.sourceforge.net
Subject: [E-devel] [PATCH] elm_diskselector has mistypo APIs
Hi,
In some elm_diskselector API and doxygen, there are simple typographical
errors.
This patch will fix it.
--
Simplify data backup and recovery for your virtual environment with vRanger.
Installation's a snap, and flexible recovery options mean your data is safe,
secure and there when you need it. Data protection magic?
Nope - It's vRanger. Get your free trial download today.
http://p.sf.net/sfu/quest-sfdev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] [Patch][Evil] evil_string has strcasestr

2011-06-21 Thread Vincent Torri

Hey

 There is no strcasestr() on MinGW Env.
 So this patch comes.. Please review the attached one.

where is strcasestr used ?

Vincent

--
Simplify data backup and recovery for your virtual environment with vRanger.
Installation's a snap, and flexible recovery options mean your data is safe,
secure and there when you need it. Data protection magic?
Nope - It's vRanger. Get your free trial download today.
http://p.sf.net/sfu/quest-sfdev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] [Patch][Evil] add some variables on evil_langinfo

2011-06-21 Thread Vincent Torri


On Wed, 22 Jun 2011, cnook wrote:

 Dear Mr. Vincent,

 Thanks for your response.
 Actually I refer to the previous version mingw-langinfo-0.1.
 Anyhow why don't you use the reference tar ball as other dependent
 modules(that is, libcurl, libgcrypt, and so on)?

sorry, i don't understand the question

Vincent

--
Simplify data backup and recovery for your virtual environment with vRanger.
Installation's a snap, and flexible recovery options mean your data is safe,
secure and there when you need it. Data protection magic?
Nope - It's vRanger. Get your free trial download today.
http://p.sf.net/sfu/quest-sfdev2dev
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel